=============================================================
ZODB storage wrapper for zlib compression of database records
=============================================================

The ``zc.zlibstorage`` package provides ZODB storage wrapper
implementations that provides compression of database records.

See src/zc/zlibstorage/README.txt.

.. image:: https://api.travis-ci.org/zopefoundation/zc.zlibstorage.png?branch=master
   :target: https://travis-ci.org/zopefoundation/zc.zlibstorage
   :alt: Build Status
